Class: SplitIoClient::SplitConfig
- Inherits:
-
Object
- Object
- SplitIoClient::SplitConfig
- Defined in:
- lib/splitclient-rb/split_config.rb
Overview
This class manages configuration options for the split client library. If not custom configuration is required the default configuration values will be used
Instance Attribute Summary collapse
-
#auth_retry_back_off_base ⇒ Object
Returns the value of attribute auth_retry_back_off_base.
-
#auth_service_url ⇒ Object
Returns the value of attribute auth_service_url.
-
#base_uri ⇒ String
The base URL for split API end points.
-
#block_until_ready ⇒ Integer
The number of seconds to wait for SDK readiness or false to disable waiting.
-
#cache_adapter ⇒ Object
The cache adapter to store splits/segments in.
-
#cache_ttl ⇒ Object
Returns the value of attribute cache_ttl.
-
#connection_timeout ⇒ Int
The connection timeout for network connections in seconds.
-
#debug_enabled ⇒ Boolean
The boolean that represents the state of the debug log level.
-
#events_adapter ⇒ Object
The cache adapter to store events in.
-
#events_push_rate ⇒ Integer
The schedule time for events flush after the first one.
-
#events_queue_size ⇒ Integer
The max size of the events queue.
-
#events_uri ⇒ String
The base URL for split events API end points.
-
#features_refresh_rate ⇒ Object
Returns the value of attribute features_refresh_rate.
-
#impression_listener ⇒ Object
Returns the value of attribute impression_listener.
-
#impression_listener_refresh_rate ⇒ Object
Returns the value of attribute impression_listener_refresh_rate.
-
#impressions_adapter ⇒ Object
The cache adapter to store impressions in.
-
#impressions_bulk_size ⇒ Object
Returns the value of attribute impressions_bulk_size.
-
#impressions_mode ⇒ Object
Returns the value of attribute impressions_mode.
-
#impressions_queue_size ⇒ Integer
How big the impressions queue is before dropping impressions.
-
#impressions_refresh_rate ⇒ Object
Returns the value of attribute impressions_refresh_rate.
-
#ip_addresses_enabled ⇒ Object
Returns the value of attribute ip_addresses_enabled.
-
#labels_enabled ⇒ Boolean
Enable logging labels and sending potentially sensitive information.
-
#language ⇒ Object
Returns the value of attribute language.
-
#localhost_mode ⇒ Object
Returns the value of attribute localhost_mode.
-
#logger ⇒ Logger
The configured logger.
-
#machine_ip ⇒ Object
Returns the value of attribute machine_ip.
-
#machine_name ⇒ Object
Returns the value of attribute machine_name.
-
#max_cache_size ⇒ Object
Returns the value of attribute max_cache_size.
-
#max_key_size ⇒ Object
Returns the value of attribute max_key_size.
-
#mode ⇒ Symbol
The mode SDK will run.
-
#read_timeout ⇒ Int
The read timeout for network connections in seconds.
-
#redis_namespace ⇒ Object
Returns the value of attribute redis_namespace.
-
#redis_url ⇒ Object
Returns the value of attribute redis_url.
-
#sdk_start_time ⇒ Object
Returns the value of attribute sdk_start_time.
-
#segments_refresh_rate ⇒ Object
Returns the value of attribute segments_refresh_rate.
-
#split_file ⇒ Object
Returns the value of attribute split_file.
-
#split_logger ⇒ SplitLogger
The split logger.
-
#split_validator ⇒ SplitValidator
The split validator.
-
#streaming_enabled ⇒ Object
Returns the value of attribute streaming_enabled.
-
#streaming_reconnect_back_off_base ⇒ Object
Returns the value of attribute streaming_reconnect_back_off_base.
-
#streaming_service_url ⇒ Object
Returns the value of attribute streaming_service_url.
-
#telemetry_adapter ⇒ Object
Returns the value of attribute telemetry_adapter.
-
#telemetry_refresh_rate ⇒ Object
Returns the value of attribute telemetry_refresh_rate.
-
#telemetry_service_url ⇒ Object
Returns the value of attribute telemetry_service_url.
-
#threads ⇒ Object
Returns the value of attribute threads.
-
#transport_debug_enabled ⇒ Boolean
Enable to log the content retrieved from endpoints.
-
#valid_mode ⇒ Object
Returns the value of attribute valid_mode.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.cache_ttl ⇒ int
The default cache time to live.
-
.default ⇒ Config
The default split client configuration.
- .default_auth_retry_back_off_base ⇒ Object
- .default_auth_service_url ⇒ Object
-
.default_base_uri ⇒ string
The default base uri for api calls.
-
.default_block_until_ready ⇒ int
The default block until ready value.
-
.default_cache_adapter ⇒ LocalStore
Configuration value for local cache store.
-
.default_connection_timeout ⇒ int
The default connection timeout value.
-
.default_debug ⇒ boolean
The default debug value.
- .default_events_push_rate ⇒ Object
- .default_events_queue_size ⇒ Object
- .default_events_uri ⇒ Object
- .default_features_refresh_rate ⇒ Object
- .default_impression_listener_refresh_rate ⇒ Object
- .default_impressions_mode ⇒ Object
- .default_impressions_queue_size ⇒ Object
- .default_impressions_refresh_rate ⇒ Object
- .default_impressions_refresh_rate_optimized ⇒ Object
-
.default_ip_addresses_enabled ⇒ boolean
The default ip addresses enabled value.
-
.default_labels_logging ⇒ boolean
The default labels logging value.
-
.default_logger ⇒ object
The default logger object.
- .default_mode ⇒ Object
- .default_offline_refresh_rate ⇒ Object
-
.default_read_timeout ⇒ int
The default read timeout value.
- .default_redis_namespace ⇒ Object
- .default_redis_url ⇒ Object
- .default_segments_refresh_rate ⇒ Object
- .default_split_file ⇒ Object
- .default_streaming_enabled ⇒ Object
- .default_streaming_reconnect_back_off_base ⇒ Object
- .default_streaming_service_url ⇒ Object
- .default_telemetry_refresh_rate ⇒ Object
- .default_telemetry_service_url ⇒ Object
- .init_auth_retry_back_off(auth_retry_back_off) ⇒ Object
- .init_cache_adapter(adapter, data_structure, queue_size = nil, redis_url = nil) ⇒ Object
- .init_impressions_refresh_rate(impressions_mode, refresh_rate, default_rate) ⇒ Object
- .init_streaming_reconnect_back_off(streaming_reconnect_back_off) ⇒ Object
- .init_telemetry_adapter(adapter, redis_url) ⇒ Object
- .init_telemetry_refresh_rate(refresh_rate) ⇒ Object
-
.machine_hostname(ip_addresses_enabled, machine_name, adapter) ⇒ string
gets the hostname where the sdk gem is running.
-
.machine_ip(ip_addresses_enabled, ip, adapter) ⇒ string
gets the ip where the sdk gem is running.
- .map_memory_adapter(name, queue_size) ⇒ Object
-
.max_cache_size ⇒ int
The default max cache size.
-
.max_key_size ⇒ int
The default max key size.
-
.transport_debug ⇒ boolean
The default transport_debug_enabled value.
Instance Method Summary collapse
- #consumer? ⇒ Boolean
- #init_impressions_mode(impressions_mode) ⇒ Object
-
#initialize(opts = {}) ⇒ type
constructor
Constructor for creating custom split client config.
-
#log_found_exception(caller, error) ⇒ void
custom logger of exceptions.
- #standalone? ⇒ Boolean
-
#startup_log ⇒ void
log which cache class was loaded and SDK mode.
Constructor Details
#initialize(opts = {}) ⇒ type
Constructor for creating custom split client config
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/splitclient-rb/split_config.rb', line 29 def initialize(opts = {}) @base_uri = (opts[:base_uri] || SplitConfig.default_base_uri).chomp('/') @events_uri = (opts[:events_uri] || SplitConfig.default_events_uri).chomp('/') @mode = opts[:mode] || SplitConfig.default_mode @redis_url = opts[:redis_url] || SplitConfig.default_redis_url @redis_namespace = opts[:redis_namespace] && opts[:redis_namespace].to_s.length > 0 ? "#{opts[:redis_namespace]}.#{SplitConfig.default_redis_namespace}" : SplitConfig.default_redis_namespace @cache_adapter = SplitConfig.init_cache_adapter( opts[:cache_adapter] || SplitConfig.default_cache_adapter, :map_adapter, nil, @redis_url ) @connection_timeout = opts[:connection_timeout] || SplitConfig.default_connection_timeout @read_timeout = opts[:read_timeout] || SplitConfig.default_read_timeout @logger = opts[:logger] || SplitConfig.default_logger if(opts[:reload_rate]) @features_refresh_rate = opts[:reload_rate] @logger.warn('Localhost mode: reload_rate will be deprecated soon in favor of ' \ 'features_refresh_rate. Take a look in our documentation.' ) else @features_refresh_rate = opts[:features_refresh_rate] || SplitConfig.default_features_refresh_rate end @segments_refresh_rate = opts[:segments_refresh_rate] || SplitConfig.default_segments_refresh_rate @impressions_mode = init_impressions_mode(opts[:impressions_mode]) @impressions_refresh_rate = SplitConfig.init_impressions_refresh_rate(@impressions_mode, opts[:impressions_refresh_rate], SplitConfig.default_impressions_refresh_rate) @impressions_queue_size = opts[:impressions_queue_size] || SplitConfig.default_impressions_queue_size @impressions_adapter = SplitConfig.init_cache_adapter( opts[:cache_adapter] || SplitConfig.default_cache_adapter, :queue_adapter, @impressions_queue_size, @redis_url ) #Safeguard for users of older SDK versions. @impressions_bulk_size = opts[:impressions_bulk_size] || @impressions_queue_size > 0 ? @impressions_queue_size : 0 @debug_enabled = opts[:debug_enabled] || SplitConfig.default_debug @transport_debug_enabled = opts[:transport_debug_enabled] || SplitConfig.default_debug @block_until_ready = SplitConfig.default_block_until_ready @ip_addresses_enabled = opts[:ip_addresses_enabled].nil? ? SplitConfig.default_ip_addresses_enabled : opts[:ip_addresses_enabled] @machine_name = SplitConfig.machine_hostname(@ip_addresses_enabled, opts[:machine_name], opts[:cache_adapter] || SplitConfig.default_cache_adapter) @machine_ip = SplitConfig.machine_ip(@ip_addresses_enabled, opts[:machine_ip], opts[:cache_adapter] || SplitConfig.default_cache_adapter) @cache_ttl = opts[:cache_ttl] || SplitConfig.cache_ttl @max_cache_size = opts[:max_cache_size] || SplitConfig.max_cache_size @language = opts[:language] || 'ruby' @version = opts[:version] || SplitIoClient::VERSION @labels_enabled = opts[:labels_enabled].nil? ? SplitConfig.default_labels_logging : opts[:labels_enabled] @impression_listener = opts[:impression_listener] @impression_listener_refresh_rate = opts[:impression_listener_refresh_rate] || SplitConfig.default_impression_listener_refresh_rate @max_key_size = SplitConfig.max_key_size @threads = {} @events_push_rate = opts[:events_push_rate] || SplitConfig.default_events_push_rate @events_queue_size = opts[:events_queue_size] || SplitConfig.default_events_queue_size @events_adapter = SplitConfig.init_cache_adapter( opts[:cache_adapter] || SplitConfig.default_cache_adapter, :queue_adapter, @events_queue_size, @redis_url ) @telemetry_adapter = SplitConfig.init_telemetry_adapter( opts[:cache_adapter] || SplitConfig.default_cache_adapter, @redis_url ) @split_file = opts[:split_file] || SplitConfig.default_split_file @valid_mode = true @split_logger = SplitIoClient::SplitLogger.new(self) @split_validator = SplitIoClient::Validators.new(self) @localhost_mode = opts[:localhost_mode] @streaming_enabled = consumer? ? false : (opts[:streaming_enabled].nil? ? SplitConfig.default_streaming_enabled : opts[:streaming_enabled]) @streaming_service_url = opts[:streaming_service_url] || SplitConfig.default_streaming_service_url @auth_service_url = opts[:auth_service_url] || SplitConfig.default_auth_service_url @auth_retry_back_off_base = SplitConfig.init_auth_retry_back_off(opts[:auth_retry_back_off_base] || SplitConfig.default_auth_retry_back_off_base) @streaming_reconnect_back_off_base = SplitConfig.init_streaming_reconnect_back_off(opts[:streaming_reconnect_back_off_base] || SplitConfig.default_streaming_reconnect_back_off_base) @telemetry_refresh_rate = SplitConfig.init_telemetry_refresh_rate(opts[:telemetry_refresh_rate]) @telemetry_service_url = opts[:telemetry_service_url] || SplitConfig.default_telemetry_service_url @sdk_start_time = Time.now startup_log end |
Instance Attribute Details
#auth_retry_back_off_base ⇒ Object
Returns the value of attribute auth_retry_back_off_base.
263 264 265 |
# File 'lib/splitclient-rb/split_config.rb', line 263 def auth_retry_back_off_base @auth_retry_back_off_base end |
#auth_service_url ⇒ Object
Returns the value of attribute auth_service_url.
261 262 263 |
# File 'lib/splitclient-rb/split_config.rb', line 261 def auth_service_url @auth_service_url end |
#base_uri ⇒ String
The base URL for split API end points
123 124 125 |
# File 'lib/splitclient-rb/split_config.rb', line 123 def base_uri @base_uri end |
#block_until_ready ⇒ Integer
The number of seconds to wait for SDK readiness or false to disable waiting
209 210 211 |
# File 'lib/splitclient-rb/split_config.rb', line 209 def block_until_ready @block_until_ready end |
#cache_adapter ⇒ Object
The cache adapter to store splits/segments in
146 147 148 |
# File 'lib/splitclient-rb/split_config.rb', line 146 def cache_adapter @cache_adapter end |
#cache_ttl ⇒ Object
Returns the value of attribute cache_ttl.
214 215 216 |
# File 'lib/splitclient-rb/split_config.rb', line 214 def cache_ttl @cache_ttl end |
#connection_timeout ⇒ Int
The connection timeout for network connections in seconds.
164 165 166 |
# File 'lib/splitclient-rb/split_config.rb', line 164 def connection_timeout @connection_timeout end |
#debug_enabled ⇒ Boolean
The boolean that represents the state of the debug log level
191 192 193 |
# File 'lib/splitclient-rb/split_config.rb', line 191 def debug_enabled @debug_enabled end |
#events_adapter ⇒ Object
The cache adapter to store events in
158 159 160 |
# File 'lib/splitclient-rb/split_config.rb', line 158 def events_adapter @events_adapter end |
#events_push_rate ⇒ Integer
The schedule time for events flush after the first one
247 248 249 |
# File 'lib/splitclient-rb/split_config.rb', line 247 def events_push_rate @events_push_rate end |
#events_queue_size ⇒ Integer
The max size of the events queue
253 254 255 |
# File 'lib/splitclient-rb/split_config.rb', line 253 def events_queue_size @events_queue_size end |
#events_uri ⇒ String
The base URL for split events API end points
129 130 131 |
# File 'lib/splitclient-rb/split_config.rb', line 129 def events_uri @events_uri end |
#features_refresh_rate ⇒ Object
Returns the value of attribute features_refresh_rate.
222 223 224 |
# File 'lib/splitclient-rb/split_config.rb', line 222 def features_refresh_rate @features_refresh_rate end |
#impression_listener ⇒ Object
Returns the value of attribute impression_listener.
226 227 228 |
# File 'lib/splitclient-rb/split_config.rb', line 226 def impression_listener @impression_listener end |
#impression_listener_refresh_rate ⇒ Object
Returns the value of attribute impression_listener_refresh_rate.
227 228 229 |
# File 'lib/splitclient-rb/split_config.rb', line 227 def impression_listener_refresh_rate @impression_listener_refresh_rate end |
#impressions_adapter ⇒ Object
The cache adapter to store impressions in
152 153 154 |
# File 'lib/splitclient-rb/split_config.rb', line 152 def impressions_adapter @impressions_adapter end |
#impressions_bulk_size ⇒ Object
Returns the value of attribute impressions_bulk_size.
234 235 236 |
# File 'lib/splitclient-rb/split_config.rb', line 234 def impressions_bulk_size @impressions_bulk_size end |
#impressions_mode ⇒ Object
Returns the value of attribute impressions_mode.
271 272 273 |
# File 'lib/splitclient-rb/split_config.rb', line 271 def impressions_mode @impressions_mode end |
#impressions_queue_size ⇒ Integer
How big the impressions queue is before dropping impressions
233 234 235 |
# File 'lib/splitclient-rb/split_config.rb', line 233 def impressions_queue_size @impressions_queue_size end |
#impressions_refresh_rate ⇒ Object
Returns the value of attribute impressions_refresh_rate.
224 225 226 |
# File 'lib/splitclient-rb/split_config.rb', line 224 def impressions_refresh_rate @impressions_refresh_rate end |
#ip_addresses_enabled ⇒ Object
Returns the value of attribute ip_addresses_enabled.
259 260 261 |
# File 'lib/splitclient-rb/split_config.rb', line 259 def ip_addresses_enabled @ip_addresses_enabled end |
#labels_enabled ⇒ Boolean
Enable logging labels and sending potentially sensitive information
203 204 205 |
# File 'lib/splitclient-rb/split_config.rb', line 203 def labels_enabled @labels_enabled end |
#language ⇒ Object
Returns the value of attribute language.
219 220 221 |
# File 'lib/splitclient-rb/split_config.rb', line 219 def language @language end |
#localhost_mode ⇒ Object
Returns the value of attribute localhost_mode.
257 258 259 |
# File 'lib/splitclient-rb/split_config.rb', line 257 def localhost_mode @localhost_mode end |
#logger ⇒ Logger
The configured logger. The client library uses the log to print warning and error messages.
171 172 173 |
# File 'lib/splitclient-rb/split_config.rb', line 171 def logger @logger end |
#machine_ip ⇒ Object
Returns the value of attribute machine_ip.
211 212 213 |
# File 'lib/splitclient-rb/split_config.rb', line 211 def machine_ip @machine_ip end |
#machine_name ⇒ Object
Returns the value of attribute machine_name.
212 213 214 |
# File 'lib/splitclient-rb/split_config.rb', line 212 def machine_name @machine_name end |
#max_cache_size ⇒ Object
Returns the value of attribute max_cache_size.
215 216 217 |
# File 'lib/splitclient-rb/split_config.rb', line 215 def max_cache_size @max_cache_size end |
#max_key_size ⇒ Object
Returns the value of attribute max_key_size.
217 218 219 |
# File 'lib/splitclient-rb/split_config.rb', line 217 def max_key_size @max_key_size end |
#mode ⇒ Symbol
The mode SDK will run
135 136 137 |
# File 'lib/splitclient-rb/split_config.rb', line 135 def mode @mode end |
#read_timeout ⇒ Int
The read timeout for network connections in seconds.
140 141 142 |
# File 'lib/splitclient-rb/split_config.rb', line 140 def read_timeout @read_timeout end |
#redis_namespace ⇒ Object
Returns the value of attribute redis_namespace.
237 238 239 |
# File 'lib/splitclient-rb/split_config.rb', line 237 def redis_namespace @redis_namespace end |
#redis_url ⇒ Object
Returns the value of attribute redis_url.
236 237 238 |
# File 'lib/splitclient-rb/split_config.rb', line 236 def redis_url @redis_url end |
#sdk_start_time ⇒ Object
Returns the value of attribute sdk_start_time.
279 280 281 |
# File 'lib/splitclient-rb/split_config.rb', line 279 def sdk_start_time @sdk_start_time end |
#segments_refresh_rate ⇒ Object
Returns the value of attribute segments_refresh_rate.
223 224 225 |
# File 'lib/splitclient-rb/split_config.rb', line 223 def segments_refresh_rate @segments_refresh_rate end |
#split_file ⇒ Object
Returns the value of attribute split_file.
255 256 257 |
# File 'lib/splitclient-rb/split_config.rb', line 255 def split_file @split_file end |
#split_logger ⇒ SplitLogger
The split logger. The client library uses the split logger to use common functions around the logger
178 179 180 |
# File 'lib/splitclient-rb/split_config.rb', line 178 def split_logger @split_logger end |
#split_validator ⇒ SplitValidator
The split validator. The client library uses the split validator to validate inputs accross the sdk
185 186 187 |
# File 'lib/splitclient-rb/split_config.rb', line 185 def split_validator @split_validator end |
#streaming_enabled ⇒ Object
Returns the value of attribute streaming_enabled.
269 270 271 |
# File 'lib/splitclient-rb/split_config.rb', line 269 def streaming_enabled @streaming_enabled end |
#streaming_reconnect_back_off_base ⇒ Object
Returns the value of attribute streaming_reconnect_back_off_base.
267 268 269 |
# File 'lib/splitclient-rb/split_config.rb', line 267 def streaming_reconnect_back_off_base @streaming_reconnect_back_off_base end |
#streaming_service_url ⇒ Object
Returns the value of attribute streaming_service_url.
265 266 267 |
# File 'lib/splitclient-rb/split_config.rb', line 265 def streaming_service_url @streaming_service_url end |
#telemetry_adapter ⇒ Object
Returns the value of attribute telemetry_adapter.
273 274 275 |
# File 'lib/splitclient-rb/split_config.rb', line 273 def telemetry_adapter @telemetry_adapter end |
#telemetry_refresh_rate ⇒ Object
Returns the value of attribute telemetry_refresh_rate.
275 276 277 |
# File 'lib/splitclient-rb/split_config.rb', line 275 def telemetry_refresh_rate @telemetry_refresh_rate end |
#telemetry_service_url ⇒ Object
Returns the value of attribute telemetry_service_url.
277 278 279 |
# File 'lib/splitclient-rb/split_config.rb', line 277 def telemetry_service_url @telemetry_service_url end |
#threads ⇒ Object
Returns the value of attribute threads.
239 240 241 |
# File 'lib/splitclient-rb/split_config.rb', line 239 def threads @threads end |
#transport_debug_enabled ⇒ Boolean
Enable to log the content retrieved from endpoints
197 198 199 |
# File 'lib/splitclient-rb/split_config.rb', line 197 def transport_debug_enabled @transport_debug_enabled end |
#valid_mode ⇒ Object
Returns the value of attribute valid_mode.
241 242 243 |
# File 'lib/splitclient-rb/split_config.rb', line 241 def valid_mode @valid_mode end |
#version ⇒ Object
Returns the value of attribute version.
220 221 222 |
# File 'lib/splitclient-rb/split_config.rb', line 220 def version @version end |
Class Method Details
.cache_ttl ⇒ int
The default cache time to live
535 536 537 |
# File 'lib/splitclient-rb/split_config.rb', line 535 def self.cache_ttl 5 end |
.default ⇒ Config
The default split client configuration
341 342 343 |
# File 'lib/splitclient-rb/split_config.rb', line 341 def self.default SplitConfig.new end |
.default_auth_retry_back_off_base ⇒ Object
321 322 323 |
# File 'lib/splitclient-rb/split_config.rb', line 321 def self.default_auth_retry_back_off_base 1 end |
.default_auth_service_url ⇒ Object
317 318 319 |
# File 'lib/splitclient-rb/split_config.rb', line 317 def self.default_auth_service_url 'https://auth.split.io/api/auth' end |
.default_base_uri ⇒ string
The default base uri for api calls
349 350 351 |
# File 'lib/splitclient-rb/split_config.rb', line 349 def self.default_base_uri 'https://sdk.split.io/api/' end |
.default_block_until_ready ⇒ int
The default block until ready value
511 512 513 |
# File 'lib/splitclient-rb/split_config.rb', line 511 def self.default_block_until_ready 15 end |
.default_cache_adapter ⇒ LocalStore
Returns configuration value for local cache store.
401 402 403 |
# File 'lib/splitclient-rb/split_config.rb', line 401 def self.default_cache_adapter :memory end |
.default_connection_timeout ⇒ int
The default connection timeout value
417 418 419 |
# File 'lib/splitclient-rb/split_config.rb', line 417 def self.default_connection_timeout 5 end |
.default_debug ⇒ boolean
The default debug value
487 488 489 |
# File 'lib/splitclient-rb/split_config.rb', line 487 def self.default_debug false end |
.default_events_push_rate ⇒ Object
445 446 447 |
# File 'lib/splitclient-rb/split_config.rb', line 445 def self.default_events_push_rate 60 end |
.default_events_queue_size ⇒ Object
449 450 451 |
# File 'lib/splitclient-rb/split_config.rb', line 449 def self.default_events_queue_size 500 end |
.default_events_uri ⇒ Object
353 354 355 |
# File 'lib/splitclient-rb/split_config.rb', line 353 def self.default_events_uri 'https://events.split.io/api/' end |
.default_features_refresh_rate ⇒ Object
421 422 423 |
# File 'lib/splitclient-rb/split_config.rb', line 421 def self.default_features_refresh_rate 5 end |
.default_impression_listener_refresh_rate ⇒ Object
437 438 439 |
# File 'lib/splitclient-rb/split_config.rb', line 437 def self.default_impression_listener_refresh_rate 0 end |
.default_impressions_mode ⇒ Object
281 282 283 |
# File 'lib/splitclient-rb/split_config.rb', line 281 def self.default_impressions_mode :optimized end |
.default_impressions_queue_size ⇒ Object
441 442 443 |
# File 'lib/splitclient-rb/split_config.rb', line 441 def self.default_impressions_queue_size 5000 end |
.default_impressions_refresh_rate ⇒ Object
429 430 431 |
# File 'lib/splitclient-rb/split_config.rb', line 429 def self.default_impressions_refresh_rate 60 end |
.default_impressions_refresh_rate_optimized ⇒ Object
433 434 435 |
# File 'lib/splitclient-rb/split_config.rb', line 433 def self.default_impressions_refresh_rate_optimized 300 end |
.default_ip_addresses_enabled ⇒ boolean
The default ip addresses enabled value
519 520 521 |
# File 'lib/splitclient-rb/split_config.rb', line 519 def self.default_ip_addresses_enabled true end |
.default_labels_logging ⇒ boolean
The default labels logging value
495 496 497 |
# File 'lib/splitclient-rb/split_config.rb', line 495 def self.default_labels_logging true end |
.default_logger ⇒ object
The default logger object
473 474 475 476 477 478 479 480 481 |
# File 'lib/splitclient-rb/split_config.rb', line 473 def self.default_logger if defined?(Rails) && Rails.logger Rails.logger elsif ENV['SPLITCLIENT_ENV'] == 'test' Logger.new('/dev/null') else Logger.new($stdout) end end |
.default_mode ⇒ Object
396 397 398 |
# File 'lib/splitclient-rb/split_config.rb', line 396 def self.default_mode :standalone end |
.default_offline_refresh_rate ⇒ Object
465 466 467 |
# File 'lib/splitclient-rb/split_config.rb', line 465 def self.default_offline_refresh_rate 5 end |
.default_read_timeout ⇒ int
The default read timeout value
409 410 411 |
# File 'lib/splitclient-rb/split_config.rb', line 409 def self.default_read_timeout 5 end |
.default_redis_namespace ⇒ Object
503 504 505 |
# File 'lib/splitclient-rb/split_config.rb', line 503 def self.default_redis_namespace 'SPLITIO' end |
.default_redis_url ⇒ Object
499 500 501 |
# File 'lib/splitclient-rb/split_config.rb', line 499 def self.default_redis_url 'redis://127.0.0.1:6379/0' end |
.default_segments_refresh_rate ⇒ Object
425 426 427 |
# File 'lib/splitclient-rb/split_config.rb', line 425 def self.default_segments_refresh_rate 60 end |
.default_split_file ⇒ Object
461 462 463 |
# File 'lib/splitclient-rb/split_config.rb', line 461 def self.default_split_file File.join(Dir.home, '.split') end |
.default_streaming_enabled ⇒ Object
309 310 311 |
# File 'lib/splitclient-rb/split_config.rb', line 309 def self.default_streaming_enabled true end |
.default_streaming_reconnect_back_off_base ⇒ Object
325 326 327 |
# File 'lib/splitclient-rb/split_config.rb', line 325 def self.default_streaming_reconnect_back_off_base 1 end |
.default_streaming_service_url ⇒ Object
313 314 315 |
# File 'lib/splitclient-rb/split_config.rb', line 313 def self.default_streaming_service_url 'https://streaming.split.io/event-stream' end |
.default_telemetry_refresh_rate ⇒ Object
453 454 455 |
# File 'lib/splitclient-rb/split_config.rb', line 453 def self.default_telemetry_refresh_rate 3600 end |
.default_telemetry_service_url ⇒ Object
457 458 459 |
# File 'lib/splitclient-rb/split_config.rb', line 457 def self.default_telemetry_service_url 'https://telemetry.split.io/api/v1' end |
.init_auth_retry_back_off(auth_retry_back_off) ⇒ Object
329 330 331 |
# File 'lib/splitclient-rb/split_config.rb', line 329 def self.init_auth_retry_back_off(auth_retry_back_off) auth_retry_back_off < 1 ? SplitConfig.default_auth_retry_back_off_base : auth_retry_back_off end |
.init_cache_adapter(adapter, data_structure, queue_size = nil, redis_url = nil) ⇒ Object
357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/splitclient-rb/split_config.rb', line 357 def self.init_cache_adapter(adapter, data_structure, queue_size = nil, redis_url = nil) case adapter when :memory SplitIoClient::Cache::Adapters::MemoryAdapter.new(map_memory_adapter(data_structure, queue_size)) when :redis begin require 'redis' rescue LoadError fail StandardError, 'To use Redis as a cache adapter you must include it in your Gemfile' end SplitIoClient::Cache::Adapters::RedisAdapter.new(redis_url) end end |
.init_impressions_refresh_rate(impressions_mode, refresh_rate, default_rate) ⇒ Object
297 298 299 300 301 |
# File 'lib/splitclient-rb/split_config.rb', line 297 def self.init_impressions_refresh_rate(impressions_mode, refresh_rate, default_rate) return (refresh_rate.nil? || refresh_rate <= 0 ? default_rate : refresh_rate) if impressions_mode == :debug return refresh_rate.nil? || refresh_rate <= 0 ? SplitConfig.default_impressions_refresh_rate_optimized : [default_rate, refresh_rate].max end |
.init_streaming_reconnect_back_off(streaming_reconnect_back_off) ⇒ Object
333 334 335 |
# File 'lib/splitclient-rb/split_config.rb', line 333 def self.init_streaming_reconnect_back_off(streaming_reconnect_back_off) streaming_reconnect_back_off < 1 ? SplitConfig.default_streaming_reconnect_back_off_base : streaming_reconnect_back_off end |
.init_telemetry_adapter(adapter, redis_url) ⇒ Object
372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/splitclient-rb/split_config.rb', line 372 def self.init_telemetry_adapter(adapter, redis_url) case adapter when :memory Telemetry::Storages::Memory.new when :redis begin require 'redis' rescue LoadError fail StandardError, 'To use Redis as a cache adapter you must include it in your Gemfile' end SplitIoClient::Cache::Adapters::RedisAdapter.new(redis_url) end end |
.init_telemetry_refresh_rate(refresh_rate) ⇒ Object
303 304 305 306 307 |
# File 'lib/splitclient-rb/split_config.rb', line 303 def self.init_telemetry_refresh_rate(refresh_rate) return SplitConfig.default_telemetry_refresh_rate if refresh_rate.nil? || refresh_rate < 60 refresh_rate end |
.machine_hostname(ip_addresses_enabled, machine_name, adapter) ⇒ string
gets the hostname where the sdk gem is running
589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/splitclient-rb/split_config.rb', line 589 def self.machine_hostname(ip_addresses_enabled, machine_name, adapter) if ip_addresses_enabled begin return machine_name || Socket.gethostname rescue return 'unknown'.freeze end else case adapter when :redis return 'NA'.freeze end end return ''.freeze end |
.machine_ip(ip_addresses_enabled, ip, adapter) ⇒ string
gets the ip where the sdk gem is running
610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 |
# File 'lib/splitclient-rb/split_config.rb', line 610 def self.machine_ip(ip_addresses_enabled, ip, adapter) if ip_addresses_enabled begin return ip unless ip.nil? || ip.to_s.empty? loopback_ip = Socket.ip_address_list.find { |ip| ip.ipv4_loopback? } private_ip = Socket.ip_address_list.find { |ip| ip.ipv4_private? } addr_info = private_ip || loopback_ip return addr_info.ip_address rescue return 'unknown'.freeze end else case adapter when :redis return 'NA'.freeze end end return ''.freeze end |
.map_memory_adapter(name, queue_size) ⇒ Object
387 388 389 390 391 392 393 394 |
# File 'lib/splitclient-rb/split_config.rb', line 387 def self.map_memory_adapter(name, queue_size) case name when :map_adapter SplitIoClient::Cache::Adapters::MemoryAdapters::MapAdapter.new when :queue_adapter SplitIoClient::Cache::Adapters::MemoryAdapters::QueueAdapter.new(queue_size) end end |
.max_cache_size ⇒ int
The default max cache size
542 543 544 |
# File 'lib/splitclient-rb/split_config.rb', line 542 def self.max_cache_size 500 end |
.max_key_size ⇒ int
The default max key size
549 550 551 |
# File 'lib/splitclient-rb/split_config.rb', line 549 def self.max_key_size 250 end |
.transport_debug ⇒ boolean
The default transport_debug_enabled value
527 528 529 |
# File 'lib/splitclient-rb/split_config.rb', line 527 def self.transport_debug false end |
Instance Method Details
#consumer? ⇒ Boolean
581 582 583 |
# File 'lib/splitclient-rb/split_config.rb', line 581 def consumer? @mode.equal?(:consumer) end |
#init_impressions_mode(impressions_mode) ⇒ Object
285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/splitclient-rb/split_config.rb', line 285 def init_impressions_mode(impressions_mode) impressions_mode ||= SplitConfig.default_impressions_mode case impressions_mode when :debug return :debug else @logger.error('You passed an invalid impressions_mode, impressions_mode should be one of the following values: :debug or :optimized. Defaulting to :optimized mode') unless impressions_mode == :optimized return :optimized end end |
#log_found_exception(caller, error) ⇒ void
This method returns an undefined value.
custom logger of exceptions
557 558 559 560 561 562 563 564 |
# File 'lib/splitclient-rb/split_config.rb', line 557 def log_found_exception(caller, error) = '' << "[splitclient-rb] Unexpected exception in #{caller}: #{error.inspect} #{error}" << "\n\t#{error.backtrace.join("\n\t")}" if @debug_enabled @logger.warn() end |
#standalone? ⇒ Boolean
577 578 579 |
# File 'lib/splitclient-rb/split_config.rb', line 577 def standalone? @mode.equal?(:standalone) end |
#startup_log ⇒ void
This method returns an undefined value.
log which cache class was loaded and SDK mode
570 571 572 573 574 575 |
# File 'lib/splitclient-rb/split_config.rb', line 570 def startup_log return if ENV['SPLITCLIENT_ENV'] == 'test' @logger.info("Loaded Ruby SDK v#{VERSION} in the #{@mode} mode") @logger.info("Loaded cache class: #{@cache_adapter.class}") end |